@@ -49,18 +49,9 @@ namespace Banshee.ClutterFlow
 		#region Fields
 		private ArtworkManager artwork_manager;
 
-		protected CoverManager coverManager;
+		private CoverManager coverManager;
 		public CoverManager CoverManager {
 			get { return coverManager; }
-			set {
-				if (coverManager!=null) {
-					coverManager.TargetIndexChanged -= HandleTargetIndexChanged;
-				}
-				coverManager = value;
-				if (coverManager!=null) {
-					coverManager.TargetIndexChanged += HandleTargetIndexChanged;
-				}
-			}
 		}
 
 		public object SyncRoot {
@@ -98,7 +89,8 @@ namespace Banshee.ClutterFlow
 		public ArtworkLookup (CoverManager coverManager)
 		{
 			//Log.Debug ("ArtworkLookup ctor ()");
-		 	CoverManager = coverManager;
+		 	this.coverManager = coverManager;
+            CoverManager.TargetIndexChanged += HandleTargetIndexChanged;
 			artwork_manager = ServiceManager.Get<ArtworkManager> ();
 			artwork_manager.AddCachedSize (CoverManager.TextureSize);
 
@@ -138,6 +130,8 @@ namespace Banshee.ClutterFlow
             if (disposed)
                 return;
             disposed = true;
+
+            CoverManager.TargetIndexChanged -= HandleTargetIndexChanged;
             Log.Debug ("ArtworkLookup Dispose ()");
 			Stop ();
             LookupQueue.Dispose ();
@@ -197,11 +191,10 @@ namespace Banshee.ClutterFlow
 					ClutterFlowAlbum cover = LookupQueue.Dequeue ();
 					float size = cover.CoverManager.TextureSize;
 					string cache_id = cover.PbId;
-					Gdk.Pixbuf pb = artwork_manager.LookupScalePixbuf (cache_id, (int) size);
-					if (pb!=null) {
-                        pb = ClutterFlowActor.MakeReflection(pb);
+					Cairo.ImageSurface surface = artwork_manager.LookupScaleSurface(cache_id, (int) size);
+					if (surface!=null) {
                         Gtk.Application.Invoke (delegate {
-                            GtkInvoke (cover, pb);
+							SetCoverToSurface(cover, surface);
                         });
 					}
                     t.IsBackground = true;
@@ -217,19 +210,17 @@ namespace Banshee.ClutterFlow
         {
             float size = cover.CoverManager.TextureSize;
             string cache_id = cover.PbId;
-            Gdk.Pixbuf pb = artwork_manager.LookupScalePixbuf (cache_id, (int) size);
-            if (pb!=null) {
-                pb = ClutterFlowActor.MakeReflection(pb);
-                GtkInvoke (cover, pb);
+            Cairo.ImageSurface surface = artwork_manager.LookupScaleSurface(cache_id, (int) size);
+            if (surface!=null) {
+                SetCoverToSurface(cover, surface);
             }
         }
 
-        private void GtkInvoke (ClutterFlowAlbum cover, Gdk.Pixbuf pb)
+        private void SetCoverToSurface (ClutterFlowAlbum cover, Cairo.ImageSurface surface)
         {
-            cover.Enqueued = false;
-            cover.SwappedToDefault = false;
-            GtkUtil.TextureSetFromPixbuf (cover.Cover, pb);
-            pb.Dispose ();
+	            cover.Enqueued = false;
+	            //cover.SwappedToDefault = false;
+				ClutterFlowActor.MakeReflection(surface, cover.Cover);
         }
 	}
 }
