@@ -43,32 +43,21 @@ namespace ClutterFlow
         event IndexChangedEventHandler IndexChanged;
     }
 
-	public delegate Gdk.Pixbuf NeedPixbuf();
+	public delegate Cairo.ImageSurface NeedSurface();
     public delegate void IndexChangedEventHandler(IIndexable item, int old_index, int new_index);
 	
 	public class TextureHolder : IDisposable {
 		#region Fields
-		protected CoverManager coverManager;
+		private CoverManager coverManager;
 		public CoverManager CoverManager {
 			get { return coverManager; }
-			set {
-				if (value!=coverManager) {
-					if (coverManager!=null) {
-						coverManager.TextureSizeChanged -= HandleTextureSizeChanged;
-					}
-					coverManager = value;
-					if (coverManager!=null) {
-						coverManager.TextureSizeChanged += HandleTextureSizeChanged;
-					}
-				}
-			}
 		}
 		
-		protected Gdk.Pixbuf default_pb;
-		public Gdk.Pixbuf DefaultPb {
+		protected Cairo.ImageSurface default_surface;
+		public Cairo.ImageSurface DefaultSurface {
 			get {
-				if (default_pb==null && GetDefaultPb!=null) default_pb = ClutterFlowActor.MakeReflection(GetDefaultPb());
-				return default_pb;
+				if (default_surface==null && GetDefaultSurface!=null) default_surface = ClutterFlowActor.MakeReflection(GetDefaultSurface());
+				return default_surface;
 			}
 		}
 		
@@ -88,28 +77,30 @@ namespace ClutterFlow
 			}
 		}
 		
-		public NeedPixbuf GetDefaultPb;
+		public NeedSurface GetDefaultSurface;
 		#endregion
 
 		#region Initialisation
-		public TextureHolder (CoverManager coverManager, NeedPixbuf getDefaultPb)
+		public TextureHolder (CoverManager coverManager, NeedSurface getDefaultSurface)
 		{
-			this.CoverManager = coverManager;
-			this.GetDefaultPb = getDefaultPb;
+			this.coverManager = coverManager;
+            CoverManager.TextureSizeChanged += HandleTextureSizeChanged;
+			this.GetDefaultSurface = getDefaultSurface;
 			ReloadDefaultTextures ();
 		}
-        ~ TextureHolder () {
-            Dispose ();
-        }
+
         protected bool disposed = false;
         public virtual void Dispose ()
         {
             if (disposed)
                 return;
             disposed = true;
-            CoverManager = null;
-            GetDefaultPb = null;
-            default_pb.Dispose ();
+
+            CoverManager.TextureSizeChanged -= HandleTextureSizeChanged;
+
+            if (default_surface != null) {
+                ((IDisposable) default_surface).Dispose ();
+            }
             Cogl.Handle.Unref (defltTexture);
             Cogl.Handle.Unref (shadeTexture);
             defltTexture = IntPtr.Zero;
@@ -119,7 +110,10 @@ namespace ClutterFlow
 
 		public void ReloadDefaultTextures ()
 		{
-			default_pb = null; //reset this so it gets reloaded
+			if (default_surface != null)
+				((IDisposable) default_surface).Dispose ();
+			default_surface = null; //reset this so it gets reloaded
+			
 			SetupDefaultTexture ();
 			SetupShadeTexture ();
 		}
@@ -127,15 +121,17 @@ namespace ClutterFlow
 		public void SetupDefaultTexture ()
 		{
 			if (defltTexture==IntPtr.Zero) {
-				if (DefaultPb!=null) {
+				if (DefaultSurface!=null) {
 					Cogl.PixelFormat fm;
-					if (DefaultPb.HasAlpha)
-						fm = PixelFormat.Rgba8888;
-					else
+					if (DefaultSurface.Format == Cairo.Format.ARGB32)
+						fm = PixelFormat.Argb8888Pre;
+					else //if (DefaultSurface.Format == Cairo.Format.RGB24)
 						fm = PixelFormat.Rgb888;
+					
 					unsafe {
-						defltTexture = ClutterHelper.cogl_texture_new_from_data((uint) DefaultPb.Width, (uint) DefaultPb.Height, Cogl.TextureFlags.None,
-						                                         fm, Cogl.PixelFormat.Any, (uint) DefaultPb.Rowstride, DefaultPb.Pixels);
+						
+						defltTexture = ClutterHelper.cogl_texture_new_from_data((uint) DefaultSurface.Width, (uint) DefaultSurface.Height, Cogl.TextureFlags.None,
+						                                         fm, Cogl.PixelFormat.Any, (uint) DefaultSurface.Stride, DefaultSurface.DataPtr);
 					}
 				} else {
 					defltTexture = Cogl.Texture.NewWithSize ((uint) coverManager.TextureSize, (uint) coverManager.TextureSize,
@@ -189,21 +185,9 @@ namespace ClutterFlow
     public abstract class ClutterFlowBaseActor : Clutter.Group, IIndexable
     {
         #region Fields
-        protected CoverManager coverManager;
+        private CoverManager coverManager;
         public virtual CoverManager CoverManager {
             get { return coverManager; }
-            set {
-                if (value!=coverManager) {
-                    if (coverManager!=null) {
-                        System.GC.SuppressFinalize (this);
-                        coverManager.Remove (this);
-                    }
-                    coverManager = value;
-                    if (coverManager!=null) {
-                        coverManager.Add (this);
-                    }
-                }
-            }
         }
 
         protected string cache_key = "";
@@ -248,13 +232,10 @@ namespace ClutterFlow
 
         public ClutterFlowBaseActor (CoverManager cover_manager) : base ()
         {
-            this.CoverManager = cover_manager;
+            coverManager = cover_manager;
+            coverManager.Add (this);
         }
 
-        ~ ClutterFlowBaseActor ()
-        {
-            Dispose ();
-        }
         protected bool disposed = false;
         public override void Dispose ()
         {
@@ -262,65 +243,64 @@ namespace ClutterFlow
                 return;
             disposed = true;
 
-            CoverManager = null;
+            coverManager.Remove (this);
+
+            base.Dispose ();
         }
 
         #region Texture Handling
-        public static Gdk.Pixbuf MakeReflection (Pixbuf pb) {
-            if (pb.BitsPerSample != 8)
-                throw new System.Exception ("Invalid bits per sample");
+        public static void MakeReflection (Cairo.ImageSurface source, CairoTexture dest) {
+	        int w = source.Width + 4;
+	        int h = source.Height * 2 + 4;
+			
+			dest.SetSurfaceSize ((uint) w, (uint) h);
 			
 			
-			Gdk.Pixbuf border_pb = new Gdk.Pixbuf(Colorspace.Rgb, true, pb.BitsPerSample, pb.Width+4, pb.Height+2);
-			border_pb.Fill (0x00000000);
-			pb.CopyArea (0, 0, pb.Width, pb.Height, border_pb, 2, 2);
 			
-			Gdk.Pixbuf final_pb = new Gdk.Pixbuf(Colorspace.Rgb, true, border_pb.BitsPerSample, border_pb.Width, border_pb.Height*2);
-
-
-            unsafe {
-
-                bool alpha = border_pb.HasAlpha;
-                int src_rowstride = border_pb.Rowstride;
-                int src_width = border_pb.Width;
-                int src_height = border_pb.Height;
-                byte * src_byte = (byte *) border_pb.Pixels;
-                byte * src_base = src_byte;
-
-                int dst_rowstride = final_pb.Rowstride;
-                int dst_width = final_pb.Width;
-                int dst_height = final_pb.Height;
-                byte * dst_byte = (byte *) final_pb.Pixels;
-                byte * dst_base = dst_byte;
-
-                byte * refl_byte = dst_base + (dst_height-1) * dst_rowstride + (dst_width-1) * 4  + 3;
-
-                for (int j = 0; j < src_height; j++) {
-                    src_byte = ((byte *) src_base) + j * src_rowstride;
-                    dst_byte = ((byte *) dst_base) + j * dst_rowstride;
-                    refl_byte = ((byte *) dst_base) + (dst_height-1-j) * dst_rowstride;
-                    for (int i = 0; i < src_width; i++) {
-                        byte r = *(src_byte++);
-                        byte g = *(src_byte++);
-                        byte b = *(src_byte++);
-                        byte a = 0xff;
-                        if (alpha)
-                            a = *(src_byte++);
-
-                        *dst_byte++ = r;
-                        *dst_byte++ = g;
-                        *dst_byte++ = b;
-                        *dst_byte++ = a;
-                        *refl_byte++ = r;
-                        *refl_byte++ = g;
-                        *refl_byte++ = b;
-                        *refl_byte++ = (byte) ((float) a * (float) (Math.Max(0, j - 0.3*src_height) / src_height));
-                    }
-                }
-            }
+			Cairo.Context context = dest.Create();
 			
-            return final_pb;
+			MakeReflection (context, source,  w, h);
+
+			//((IDisposable) context.Target).Dispose();
+			((IDisposable) context).Dispose();
         }
+		
+		
+        public static Cairo.ImageSurface MakeReflection (Cairo.ImageSurface source) {
+	        int w = source.Width + 4;
+	        int h = source.Height * 2 + 4;
+			
+			Cairo.ImageSurface dest = new Cairo.ImageSurface(Cairo.Format.ARGB32, w, h);
+			Cairo.Context context = new Cairo.Context(dest);
+	
+			MakeReflection (context, source, w, h);
+
+			//((IDisposable) context.Target).Dispose();
+			((IDisposable) context).Dispose();
+			
+			return dest;
+        }
+		
+		private static void MakeReflection (Cairo.Context context, Cairo.ImageSurface source, int w, int h) {
+
+			context.ResetClip ();			
+			context.SetSourceSurface(source, 2, 2);
+	        context.Paint();
+			
+	        double alpha = -0.3;
+	        double step = 1.0 / (double) source.Height;
+
+			context.Translate(0, h);
+			context.Scale (1, -1);
+			context.SetSourceSurface(source, 2, 2);
+	        for (int i = 0; i < source.Height; i++) {
+				context.Rectangle(0, i+2, w, 1);
+	            context.Clip();
+				alpha += step;
+	            context.PaintWithAlpha(Math.Max(Math.Min(alpha, 0.7), 0.0));
+	            context.ResetClip();
+			}
+		}
         #endregion
     }
 
@@ -339,10 +319,10 @@ namespace ClutterFlow
             protected set { is_setup = value; }
         }
 
-        private bool swapped = false;
-        private bool delayed_cover_swap = false;
+       /* private bool swapped = false;
+        private bool delayed_cover_swap = false;*/
         private bool delayed_shade_swap = false;
-        public bool SwappedToDefault {
+        /*public bool SwappedToDefault {
             get { return swapped; }
             set {
                 if (value!=swapped) {
@@ -353,15 +333,15 @@ namespace ClutterFlow
                         SetCoverSwap ();
                 }
             }
-        }
+        }*/
 		
 		protected bool CanUseShader {
 			get {
-				return ClutterHelper.CheckForExtension ("GL_ARB_vertex_shader");
+				return Clutter.Feature.Available (Clutter.FeatureFlags.ShadersGlsl);
 			}
 		}
 		
-        private void SetCoverSwap () {
+        /*private void SetCoverSwap () {
             if (swapped) {
                 cover.CoglTexture = textureHolder.DefaultTexture;
             } else {
@@ -369,7 +349,7 @@ namespace ClutterFlow
                                                              Cogl.TextureFlags.NoSlicing, Cogl.PixelFormat.Argb8888);
             }
             delayed_cover_swap = false;
-        }
+        }*/
 
         private void SetShadeSwap () {
 			if (!has_shader) {
@@ -378,8 +358,8 @@ namespace ClutterFlow
 			}
         }
 
-        protected Clutter.Texture cover = null;
-        public Clutter.Texture Cover {
+        protected Clutter.CairoTexture cover = null;
+        public Clutter.CairoTexture Cover {
             get { return cover; }
         }
         protected Clutter.Texture shade = null;
@@ -388,56 +368,45 @@ namespace ClutterFlow
         }
 
 
-        public override CoverManager CoverManager {
-            get { return base.CoverManager; }
-            set {
-                if (coverManager!=null)
-                    coverManager.TextureSizeChanged -= HandleTextureSizeChanged;
-                base.CoverManager = value;
-                if (coverManager!=null)
-                    coverManager.TextureSizeChanged += HandleTextureSizeChanged;
-            }
-        }
-
-		private NeedPixbuf getDefaultPb;
+		private NeedSurface getDefaultSurface;
 		
 		protected bool shifted_outwards;
 		#endregion
 		
 		#region Initialization	
-		public ClutterFlowActor (CoverManager cover_manager, NeedPixbuf getDefaultPb) : base (cover_manager)
+		public ClutterFlowActor (CoverManager cover_manager, NeedSurface getDefaultSurface) : base (cover_manager)
 		{
-			this.getDefaultPb = getDefaultPb;
+			this.getDefaultSurface = getDefaultSurface;
 
             this.ParentSet += HandleParentSet;
 			this.LeaveEvent += HandleLeaveEvent;
 			this.ButtonPressEvent += HandleButtonPressEvent;
 			this.ButtonReleaseEvent += HandleButtonReleaseEvent;
-			
+
+            CoverManager.TextureSizeChanged += HandleTextureSizeChanged;
+
 			IsSetup = SetupStatics ();
 			SetupActors ();
 		}
 
-        ~ ClutterFlowActor ()
-        {
-            Dispose ();
-        }
         public sealed override void Dispose ()
         {
-            base.Dispose ();
-
             this.ParentSet -= HandleParentSet;
 			this.LeaveEvent -= HandleLeaveEvent;
             this.ButtonPressEvent -= HandleButtonPressEvent;
             this.ButtonReleaseEvent -= HandleButtonReleaseEvent;
-            getDefaultPb = null;
+
+            CoverManager.TextureSizeChanged -= HandleTextureSizeChanged;
+            getDefaultSurface = null;
 
             DisposeStatics ();
+
+            base.Dispose ();
         }
 		protected virtual bool SetupStatics ()
 		{
 			if (textureHolder==null)
-				textureHolder = new TextureHolder(CoverManager, GetDefaultPb);
+				textureHolder = new TextureHolder(CoverManager, getDefaultSurface);
 			return true;
 		}
         protected virtual void DisposeStatics ()
@@ -465,7 +434,7 @@ namespace ClutterFlow
 		protected bool has_shader = false;
 		protected virtual void TryShading ()
 		{
-			if (CanUseShader/*Clutter.Feature.Available (Clutter.FeatureFlags.ShadersGlsl)*/) {
+			/*if (CanUseShader) {
 				shader = new Clutter.Shader ();
 				shader.VertexSource = @"
 					attribute vec4 gl_Color;
@@ -497,22 +466,22 @@ namespace ClutterFlow
 				OnAngleChanged (this, new GLib.NotifyArgs());
 				OnAnchorChanged (this, new GLib.NotifyArgs());
 				has_shader = true;
-			}
+			}*/
 		}
 		
 		protected virtual void SetupCover ()
 		{
 			if (cover==null) {
-				cover = new Clutter.Texture();				
+				cover = new Clutter.CairoTexture((uint) CoverManager.TextureSize, (uint) CoverManager.TextureSize*2);
 				Add (cover);
 				cover.Show ();
 				cover.Realize ();
 			}
-			cover.SetSize (coverManager.Behaviour.CoverWidth, coverManager.Behaviour.CoverWidth*2);
+			cover.SetSize (CoverManager.Behaviour.CoverWidth, CoverManager.Behaviour.CoverWidth*2);
 			cover.SetPosition (0, 0);
 			cover.Opacity = 255;
 			
-			SwappedToDefault = true;
+			//SwappedToDefault = true;
 		}
 		
 		protected virtual void OnOpacityChanged (object sender, NotifyArgs args)
@@ -542,7 +511,7 @@ namespace ClutterFlow
 					else
 						delayed_shade_swap = true;
 				}
-				shade.SetSize (coverManager.Behaviour.CoverWidth, coverManager.Behaviour.CoverWidth*2);
+				shade.SetSize (CoverManager.Behaviour.CoverWidth, CoverManager.Behaviour.CoverWidth*2);
 				shade.SetPosition (0, 0);
 				shade.Opacity = 255;
 	
@@ -552,9 +521,9 @@ namespace ClutterFlow
 		#endregion
 
 		#region Texture Handling
-		protected virtual Gdk.Pixbuf GetDefaultPb ()
+		protected virtual Cairo.ImageSurface GetDefaultSurface ()
 		{
-			return (getDefaultPb!=null) ? getDefaultPb() : null;
+			return (getDefaultSurface!=null) ? getDefaultSurface() : null;
 		}
 
 		protected virtual void HandleTextureSizeChanged(object sender, EventArgs e)
@@ -580,7 +549,7 @@ namespace ClutterFlow
 			if (CoverManager.CurrentCover!=this)
 				CoverManager.NewCurrentCover += HandleNewCurrentCover;
 			else
-				coverManager.Behaviour.CreateClickedCloneAnimation (this);
+				CoverManager.Behaviour.CreateClickedCloneAnimation (this);
 			return this;
 		}
 		
@@ -588,7 +557,7 @@ namespace ClutterFlow
 		{
 			if (CoverManager.CurrentCover==this) {
 				CoverManager.NewCurrentCover -= HandleNewCurrentCover;
-				coverManager.Behaviour.CreateClickedCloneAnimation (this, CoverManager.MaxAnimationSpan);
+				CoverManager.Behaviour.CreateClickedCloneAnimation (this, CoverManager.MaxAnimationSpan);
 			}
 		}
 
@@ -625,7 +594,7 @@ namespace ClutterFlow
         {
             if (this.Stage != null) {
                 if (delayed_shade_swap) SetShadeSwap ();
-                if (delayed_cover_swap) SetCoverSwap ();
+                //if (delayed_cover_swap) SetCoverSwap ();
             }
         }
 
