@@ -114,17 +114,16 @@ namespace ClutterFlow
 			letter_lookup = new Dictionary<AlphabetChars, int>();
 			foreach (AlphabetChars key in Enum.GetValues(typeof(AlphabetChars)))
 				letter_lookup.Add(key, -1);
-			Console.WriteLine ("ResetLetterLookup called, letter_lookup is " + (letter_lookup == null ? "null" : "not null"));
 		}
 		public void UpdateLetterLookup (ClutterFlowBaseActor actor) {
-			string label = actor.SortLabel.ToUpper ();
+			string label = actor.SortLabel.ToUpper ().Normalize (System.Text.NormalizationForm.FormKD);
 			char letter = label.Length>0 ? char.Parse(label.Substring (0,1)) : '?';
-			AlphabetChars key;
+            AlphabetChars key;
 			if (char.IsLetter(letter))
 				key = (AlphabetChars) letter;
 			else
-				key = AlphabetChars.unkown;
-			if (letter_lookup[key]==-1)
+				key = AlphabetChars.unknown;
+			if (letter_lookup.ContainsKey (key) && letter_lookup[key] == -1)
 				letter_lookup[key] = actor.Index;
 		}
 		
@@ -245,6 +244,10 @@ namespace ClutterFlow
 
         public override void Dispose ()
         {
+            if (reload_timeout > 0) {
+                GLib.Source.Remove (reload_timeout);
+            }
+
             ActorLoader.Dispose ();
             Behaviour.Dispose ();
             timeline.Dispose ();
@@ -282,12 +285,12 @@ namespace ClutterFlow
 			}
 		}
 		
-		private int reload_timeout = -1;
+		private uint reload_timeout = 0;
 		internal void ReloadCovers ()
 		{
-			if (reload_timeout!=-1)
-				GLib.Source.Remove((uint) reload_timeout);
-			reload_timeout = (int) GLib.Timeout.Add (MaxAnimationSpan, new GLib.TimeoutHandler (reload_covers));
+			if (reload_timeout > 0)
+				GLib.Source.Remove(reload_timeout);
+			reload_timeout = GLib.Timeout.Add (MaxAnimationSpan, new GLib.TimeoutHandler (reload_covers));
 		}
 
      	private bool reload_covers ()
